from . import column_pb2 as _column_pb2
from . import domain_pb2 as _domain_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PolicyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    POLICY_TYPE_UNSPECIFIED: _ClassVar[PolicyType]
    POLICY_TYPE_FILTER_POLICY: _ClassVar[PolicyType]
    POLICY_TYPE_DECRYPTION_POLICY: _ClassVar[PolicyType]
    POLICY_TYPE_MASKING_POLICY: _ClassVar[PolicyType]
    POLICY_TYPE_BLOCK_POLICY: _ClassVar[PolicyType]
    POLICY_TYPE_ALLOW_POLICY: _ClassVar[PolicyType]
    POLICY_TYPE_IMPERSONATE_POLICY: _ClassVar[PolicyType]
POLICY_TYPE_UNSPECIFIED: PolicyType
POLICY_TYPE_FILTER_POLICY: PolicyType
POLICY_TYPE_DECRYPTION_POLICY: PolicyType
POLICY_TYPE_MASKING_POLICY: PolicyType
POLICY_TYPE_BLOCK_POLICY: PolicyType
POLICY_TYPE_ALLOW_POLICY: PolicyType
POLICY_TYPE_IMPERSONATE_POLICY: PolicyType

class TriggeredPolicy(_message.Message):
    __slots__ = ("policy_id", "owners", "notify", "policy_type", "reason", "contextual_data", "policy_status")
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    NOTIFY_FIELD_NUMBER: _ClassVar[int]
    POLICY_TYPE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    CONTEXTUAL_DATA_FIELD_NUMBER: _ClassVar[int]
    POLICY_STATUS_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    notify: str
    policy_type: PolicyType
    reason: str
    contextual_data: str
    policy_status: str
    def __init__(self, policy_id: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., notify: _Optional[str] = ..., policy_type: _Optional[_Union[PolicyType, str]] = ..., reason: _Optional[str] = ..., contextual_data: _Optional[str] = ..., policy_status: _Optional[str] = ...) -> None: ...

class TriggeredFilterPolicy(_message.Message):
    __slots__ = ("interval", "limit", "count")
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    interval: str
    limit: int
    count: int
    def __init__(self, interval: _Optional[str] = ..., limit: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...

class TriggeredDecryptionPolicy(_message.Message):
    __slots__ = ("column_path",)
    COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
    column_path: str
    def __init__(self, column_path: _Optional[str] = ...) -> None: ...

class TriggeredMaskingPolicy(_message.Message):
    __slots__ = ("column_path", "masking_type", "typesafe")
    COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
    MASKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPESAFE_FIELD_NUMBER: _ClassVar[int]
    column_path: str
    masking_type: str
    typesafe: bool
    def __init__(self, column_path: _Optional[str] = ..., masking_type: _Optional[str] = ..., typesafe: bool = ...) -> None: ...

class TriggeredBlockPolicy(_message.Message):
    __slots__ = ("object_type", "path", "object_paths", "multiple", "action", "datastore_is_default_block")
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    OBJECT_PATHS_FIELD_NUMBER: _ClassVar[int]
    MULTIPLE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_IS_DEFAULT_BLOCK_FIELD_NUMBER: _ClassVar[int]
    object_type: str
    path: str
    object_paths: _containers.RepeatedScalarFieldContainer[str]
    multiple: bool
    action: str
    datastore_is_default_block: bool
    def __init__(self, object_type: _Optional[str] = ..., path: _Optional[str] = ..., object_paths: _Optional[_Iterable[str]] = ..., multiple: bool = ..., action: _Optional[str] = ..., datastore_is_default_block: bool = ...) -> None: ...

class TiggeredAllowPolicy(_message.Message):
    __slots__ = ("object_type", "path")
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    object_type: str
    path: str
    def __init__(self, object_type: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class LogRequest(_message.Message):
    __slots__ = ("start_time", "end_time", "sidecar_processing_time", "data_store_start_time", "data_store_end_time", "data_store_processing_time", "query", "success", "error_message", "stament_type", "returned_tables", "returned_columns", "data_volume", "end_user_id", "end_user_db_user_name", "end_user_external_ids", "policy_action", "returned_rows_count", "returned_rows_count_by_server", "returned_rows_count_to_user", "filtered_rows_count", "triggered_policies", "tenant_id", "row_level_metrics", "tenant_id_column_name", "tenant_mismatch", "bucket_name", "s3_action", "returned_objects", "ssh_aws_connection_type", "ssh_aws_arn", "end_user_groups", "user_groups", "groups", "fingerprint", "data_domains", "request_body", "response_body", "request_body_encrypted", "response_body_encrypted", "request_body_post_policies_action", "response_body_post_policies_action", "request_body_post_policies_dry_run", "response_body_post_policies_dry_run")
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_PROCESSING_TIME_FIELD_NUMBER: _ClassVar[int]
    DATA_STORE_START_TIME_FIELD_NUMBER: _ClassVar[int]
    DATA_STORE_END_TIME_FIELD_NUMBER: _ClassVar[int]
    DATA_STORE_PROCESSING_TIME_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STAMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    RETURNED_TABLES_FIELD_NUMBER: _ClassVar[int]
    RETURNED_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    DATA_VOLUME_FIELD_NUMBER: _ClassVar[int]
    END_USER_ID_FIELD_NUMBER: _ClassVar[int]
    END_USER_DB_USER_NAME_FIELD_NUMBER: _ClassVar[int]
    END_USER_EXTERNAL_IDS_FIELD_NUMBER: _ClassVar[int]
    POLICY_ACTION_FIELD_NUMBER: _ClassVar[int]
    RETURNED_ROWS_COUNT_FIELD_NUMBER: _ClassVar[int]
    RETURNED_ROWS_COUNT_BY_SERVER_FIELD_NUMBER: _ClassVar[int]
    RETURNED_ROWS_COUNT_TO_USER_FIELD_NUMBER: _ClassVar[int]
    FILTERED_ROWS_COUNT_FIELD_NUMBER: _ClassVar[int]
    TRIGGERED_POLICIES_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    ROW_LEVEL_METRICS_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_COLUMN_NAME_FIELD_NUMBER: _ClassVar[int]
    TENANT_MISMATCH_FIELD_NUMBER: _ClassVar[int]
    BUCKET_NAME_FIELD_NUMBER: _ClassVar[int]
    S3_ACTION_FIELD_NUMBER: _ClassVar[int]
    RETURNED_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    SSH_AWS_CONNECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    SSH_AWS_ARN_FIELD_NUMBER: _ClassVar[int]
    END_USER_GROUPS_FIELD_NUMBER: _ClassVar[int]
    USER_GROUPS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    DATA_DOMAINS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_POST_POLICIES_ACTION_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_POST_POLICIES_ACTION_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_POST_POLICIES_DRY_RUN_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_POST_POLICIES_DRY_RUN_FIELD_NUMBER: _ClassVar[int]
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    sidecar_processing_time: _duration_pb2.Duration
    data_store_start_time: _timestamp_pb2.Timestamp
    data_store_end_time: _timestamp_pb2.Timestamp
    data_store_processing_time: _duration_pb2.Duration
    query: str
    success: bool
    error_message: str
    stament_type: str
    returned_tables: _containers.RepeatedScalarFieldContainer[str]
    returned_columns: _containers.RepeatedCompositeFieldContainer[_column_pb2.Column]
    data_volume: int
    end_user_id: str
    end_user_db_user_name: str
    end_user_external_ids: _containers.RepeatedScalarFieldContainer[str]
    policy_action: str
    returned_rows_count: int
    returned_rows_count_by_server: int
    returned_rows_count_to_user: int
    filtered_rows_count: int
    triggered_policies: _containers.RepeatedCompositeFieldContainer[TriggeredPolicy]
    tenant_id: str
    row_level_metrics: _containers.RepeatedCompositeFieldContainer[RowLevelMetric]
    tenant_id_column_name: str
    tenant_mismatch: _containers.RepeatedScalarFieldContainer[str]
    bucket_name: str
    s3_action: str
    returned_objects: _containers.RepeatedCompositeFieldContainer[S3Object]
    ssh_aws_connection_type: str
    ssh_aws_arn: str
    end_user_groups: _containers.RepeatedScalarFieldContainer[str]
    user_groups: _containers.RepeatedScalarFieldContainer[str]
    groups: _containers.RepeatedScalarFieldContainer[str]
    fingerprint: str
    data_domains: _containers.RepeatedCompositeFieldContainer[_domain_pb2.Domain]
    request_body: str
    response_body: str
    request_body_encrypted: bool
    response_body_encrypted: bool
    request_body_post_policies_action: str
    response_body_post_policies_action: str
    request_body_post_policies_dry_run: str
    response_body_post_policies_dry_run: str
    def __init__(self, start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sidecar_processing_time: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., data_store_start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., data_store_end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., data_store_processing_time: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., query: _Optional[str] = ..., success: bool = ..., error_message: _Optional[str] = ..., stament_type: _Optional[str] = ..., returned_tables: _Optional[_Iterable[str]] = ..., returned_columns: _Optional[_Iterable[_Union[_column_pb2.Column, _Mapping]]] = ..., data_volume: _Optional[int] = ..., end_user_id: _Optional[str] = ..., end_user_db_user_name: _Optional[str] = ..., end_user_external_ids: _Optional[_Iterable[str]] = ..., policy_action: _Optional[str] = ..., returned_rows_count: _Optional[int] = ..., returned_rows_count_by_server: _Optional[int] = ..., returned_rows_count_to_user: _Optional[int] = ..., filtered_rows_count: _Optional[int] = ..., triggered_policies: _Optional[_Iterable[_Union[TriggeredPolicy, _Mapping]]] = ..., tenant_id: _Optional[str] = ..., row_level_metrics: _Optional[_Iterable[_Union[RowLevelMetric, _Mapping]]] = ..., tenant_id_column_name: _Optional[str] = ..., tenant_mismatch: _Optional[_Iterable[str]] = ..., bucket_name: _Optional[str] = ..., s3_action: _Optional[str] = ..., returned_objects: _Optional[_Iterable[_Union[S3Object, _Mapping]]] = ..., ssh_aws_connection_type: _Optional[str] = ..., ssh_aws_arn: _Optional[str] = ..., end_user_groups: _Optional[_Iterable[str]] = ..., user_groups: _Optional[_Iterable[str]] = ..., groups: _Optional[_Iterable[str]] = ..., fingerprint: _Optional[str] = ..., data_domains: _Optional[_Iterable[_Union[_domain_pb2.Domain, _Mapping]]] = ..., request_body: _Optional[str] = ..., response_body: _Optional[str] = ..., request_body_encrypted: bool = ..., response_body_encrypted: bool = ..., request_body_post_policies_action: _Optional[str] = ..., response_body_post_policies_action: _Optional[str] = ..., request_body_post_policies_dry_run: _Optional[str] = ..., response_body_post_policies_dry_run: _Optional[str] = ...) -> None: ...

class Session(_message.Message):
    __slots__ = ("id", "start_time", "datastore_id", "datastore_name", "datastore_technology", "datastore_deployment_type", "server_ip_address", "client_ip_address", "user_id", "user_type", "db_user", "db_name", "application_name", "schemas", "native_role_id", "native_role_assignment", "sidecar_id", "sidecar_name", "sidecar_technology", "aws_account_id", "aws_region", "aws_ec2_instance_id", "aws_ecs_cluster_name", "aws_ecs_cluster_arn", "aws_ecs_service_name", "aws_ecs_service_arn", "aws_ecs_task_id", "aws_ecs_task_arn", "container_name")
    ID_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_DEPLOYMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVER_IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    USER_TYPE_FIELD_NUMBER: _ClassVar[int]
    DB_USER_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_ROLE_ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_NAME_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    AWS_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_REGION_FIELD_NUMBER: _ClassVar[int]
    AWS_EC2_INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_CLUSTER_NAME_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_CLUSTER_ARN_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_SERVICE_ARN_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_TASK_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_ECS_TASK_ARN_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    start_time: int
    datastore_id: str
    datastore_name: str
    datastore_technology: str
    datastore_deployment_type: str
    server_ip_address: str
    client_ip_address: str
    user_id: str
    user_type: str
    db_user: str
    db_name: str
    application_name: str
    schemas: _containers.RepeatedScalarFieldContainer[str]
    native_role_id: str
    native_role_assignment: str
    sidecar_id: str
    sidecar_name: str
    sidecar_technology: str
    aws_account_id: str
    aws_region: str
    aws_ec2_instance_id: str
    aws_ecs_cluster_name: str
    aws_ecs_cluster_arn: str
    aws_ecs_service_name: str
    aws_ecs_service_arn: str
    aws_ecs_task_id: str
    aws_ecs_task_arn: str
    container_name: str
    def __init__(self, id: _Optional[str] = ..., start_time: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., datastore_technology: _Optional[str] = ..., datastore_deployment_type: _Optional[str] = ..., server_ip_address: _Optional[str] = ..., client_ip_address: _Optional[str] = ..., user_id: _Optional[str] = ..., user_type: _Optional[str] = ..., db_user: _Optional[str] = ..., db_name: _Optional[str] = ..., application_name: _Optional[str] = ..., schemas: _Optional[_Iterable[str]] = ..., native_role_id: _Optional[str] = ..., native_role_assignment: _Optional[str] = ..., sidecar_id: _Optional[str] = ..., sidecar_name: _Optional[str] = ..., sidecar_technology: _Optional[str] = ..., aws_account_id: _Optional[str] = ..., aws_region: _Optional[str] = ..., aws_ec2_instance_id: _Optional[str] = ..., aws_ecs_cluster_name: _Optional[str] = ..., aws_ecs_cluster_arn: _Optional[str] = ..., aws_ecs_service_name: _Optional[str] = ..., aws_ecs_service_arn: _Optional[str] = ..., aws_ecs_task_id: _Optional[str] = ..., aws_ecs_task_arn: _Optional[str] = ..., container_name: _Optional[str] = ...) -> None: ...

class FormalLog(_message.Message):
    __slots__ = ("id", "datastore_id", "session", "request", "created_at", "timestamp", "total")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    session: Session
    request: LogRequest
    created_at: str
    timestamp: _timestamp_pb2.Timestamp
    total: int
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., session: _Optional[_Union[Session, _Mapping]] = ..., request: _Optional[_Union[LogRequest, _Mapping]] = ..., created_at: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., total: _Optional[int] = ...) -> None: ...

class TenantLogsInfra(_message.Message):
    __slots__ = ("uri", "password", "username", "metrics_role_pwd")
    URI_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    METRICS_ROLE_PWD_FIELD_NUMBER: _ClassVar[int]
    uri: str
    password: str
    username: str
    metrics_role_pwd: str
    def __init__(self, uri: _Optional[str] = ..., password: _Optional[str] = ..., username: _Optional[str] = ..., metrics_role_pwd: _Optional[str] = ...) -> None: ...

class LogStorageS3(_message.Message):
    __slots__ = ("s3_firehose_stream_arn",)
    S3_FIREHOSE_STREAM_ARN_FIELD_NUMBER: _ClassVar[int]
    s3_firehose_stream_arn: str
    def __init__(self, s3_firehose_stream_arn: _Optional[str] = ...) -> None: ...

class CsvOrParquetColumn(_message.Message):
    __slots__ = ("col_index", "name", "data_type")
    COL_INDEX_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    col_index: int
    name: str
    data_type: str
    def __init__(self, col_index: _Optional[int] = ..., name: _Optional[str] = ..., data_type: _Optional[str] = ...) -> None: ...

class Image(_message.Message):
    __slots__ = ("name", "faces_count", "width", "height", "type", "policy_action")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FACES_COUNT_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POLICY_ACTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    faces_count: int
    width: int
    height: int
    type: str
    policy_action: str
    def __init__(self, name: _Optional[str] = ..., faces_count: _Optional[int] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., type: _Optional[str] = ..., policy_action: _Optional[str] = ...) -> None: ...

class S3Object(_message.Message):
    __slots__ = ("name", "content_type", "content_length", "columns", "image")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    name: str
    content_type: str
    content_length: int
    columns: _containers.RepeatedCompositeFieldContainer[CsvOrParquetColumn]
    image: Image
    def __init__(self, name: _Optional[str] = ..., content_type: _Optional[str] = ..., content_length: _Optional[int] = ..., columns: _Optional[_Iterable[_Union[CsvOrParquetColumn, _Mapping]]] = ..., image: _Optional[_Union[Image, _Mapping]] = ...) -> None: ...

class RowLevelMetric(_message.Message):
    __slots__ = ("datastore_id", "datastore_name", "end_user_id", "end_user_db_username", "user_id", "db_user", "db_name", "schema_name", "table_name", "path", "hashed_row_level_value", "clear_text_row_level_value", "ts", "counter", "returned_rows", "timebucket")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    END_USER_ID_FIELD_NUMBER: _ClassVar[int]
    END_USER_DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    DB_USER_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    HASHED_ROW_LEVEL_VALUE_FIELD_NUMBER: _ClassVar[int]
    CLEAR_TEXT_ROW_LEVEL_VALUE_FIELD_NUMBER: _ClassVar[int]
    TS_FIELD_NUMBER: _ClassVar[int]
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    RETURNED_ROWS_FIELD_NUMBER: _ClassVar[int]
    TIMEBUCKET_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    datastore_name: str
    end_user_id: str
    end_user_db_username: str
    user_id: str
    db_user: str
    db_name: str
    schema_name: str
    table_name: str
    path: str
    hashed_row_level_value: str
    clear_text_row_level_value: str
    ts: _timestamp_pb2.Timestamp
    counter: int
    returned_rows: int
    timebucket: _timestamp_pb2.Timestamp
    def __init__(self, datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., end_user_id: _Optional[str] = ..., end_user_db_username: _Optional[str] = ..., user_id: _Optional[str] = ..., db_user: _Optional[str] = ..., db_name: _Optional[str] = ..., schema_name: _Optional[str] = ..., table_name: _Optional[str] = ..., path: _Optional[str] = ..., hashed_row_level_value: _Optional[str] = ..., clear_text_row_level_value: _Optional[str] = ..., ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., counter: _Optional[int] = ..., returned_rows: _Optional[int] = ..., timebucket: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/github_repository.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/github_repository.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)admin/v1/types/v1/github_repository.proto\x12\x11\x61\x64min.v1.types.v1\"Z\n\x10GithubRepository\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x1b\n\tfull_name\x18\x02 \x01(\tR\x08\x66ullName\x12\x19\n\x08html_url\x18\x03 \x01(\tR\x07htmlUrlB\xe3\x01\n\x15\x63om.admin.v1.types.v1B\x15GithubRepositoryProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.github_repository_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\025GithubRepositoryProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_GITHUBREPOSITORY']._serialized_start=64
  _globals['_GITHUBREPOSITORY']._serialized_end=154
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateNativeUserRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id", "native_user_secret", "use_as_default", "termination_protection")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    USE_AS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    native_user_secret: str
    use_as_default: bool
    termination_protection: bool
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ..., use_as_default: bool = ..., termination_protection: bool = ...) -> None: ...

class CreateNativeUserResponse(_message.Message):
    __slots__ = ("native_user",)
    NATIVE_USER_FIELD_NUMBER: _ClassVar[int]
    native_user: NativeUser
    def __init__(self, native_user: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...

class GetNativeUsersRequest(_message.Message):
    __slots__ = ("data_store_id",)
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    def __init__(self, data_store_id: _Optional[str] = ...) -> None: ...

class GetNativeUsersResponse(_message.Message):
    __slots__ = ("native_users",)
    class NativeUsersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: NativeUser
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...
    NATIVE_USERS_FIELD_NUMBER: _ClassVar[int]
    native_users: _containers.MessageMap[str, NativeUser]
    def __init__(self, native_users: _Optional[_Mapping[str, NativeUser]] = ...) -> None: ...

class GetNativeUserRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class GetNativeUserResponse(_message.Message):
    __slots__ = ("native_user",)
    NATIVE_USER_FIELD_NUMBER: _ClassVar[int]
    native_user: NativeUser
    def __init__(self, native_user: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...

class NativeUser(_message.Message):
    __slots__ = ("datastore_id", "native_user_id", "native_user_secret", "use_as_default", "created_at", "users", "groups", "id", "termination_protection")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    USE_AS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    native_user_id: str
    native_user_secret: str
    use_as_default: bool
    created_at: int
    users: _containers.RepeatedScalarFieldContainer[str]
    groups: _containers.RepeatedScalarFieldContainer[str]
    id: str
    termination_protection: bool
    def __init__(self, datastore_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ..., use_as_default: bool = ..., created_at: _Optional[int] = ..., users: _Optional[_Iterable[str]] = ..., groups: _Optional[_Iterable[str]] = ..., id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class DeleteNativeUserRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class DeleteNativeUserResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateNativeUserSecretRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id", "native_user_secret")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    native_user_secret: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ...) -> None: ...

class UpdateNativeUserSecretResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetNativeUserAsDefaultRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class SetNativeUserAsDefaultResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetNativeUserTerminationProtectionRequest(_message.Message):
    __slots__ = ("id", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class SetNativeUserTerminationProtectionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ("data_store_id", "native_user_id", "identity_id", "formal_identity_type", "termination_protection")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    identity_id: str
    formal_identity_type: str
    termination_protection: bool
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class GetNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ("data_store_id", "identity_id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    identity_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...

class CreateNativeUserIdentityLinkV2Request(_message.Message):
    __slots__ = ("data_store_id", "native_user_id", "identity_id", "formal_identity_type", "termination_protection")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    identity_id: str
    formal_identity_type: str
    termination_protection: bool
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateNativeUserIdentityLinkV2Response(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class GetNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class DeleteNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ("data_store_id", "identity_id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    identity_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...

class DeleteNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ("id", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class UpdateNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class NativeUserLink(_message.Message):
    __slots__ = ("data_store_id", "formal_identity_id", "formal_identity_type", "native_user_id", "termination_protection", "id")
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    formal_identity_id: str
    formal_identity_type: str
    native_user_id: str
    termination_protection: bool
    id: str
    def __init__(self, data_store_id: _Optional[str] = ..., formal_identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ..., native_user_id: _Optional[str] = ..., termination_protection: bool = ..., id: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_code_repository_pb2 as admin_dot_v1_dot_integration__code__repository__pb2


class CodeRepositoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeleteCodeRepoById = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/DeleteCodeRepoById',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdResponse.FromString,
                _registered_method=True)
        self.CancelDeleteCodeRepoById = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/CancelDeleteCodeRepoById',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdResponse.FromString,
                _registered_method=True)
        self.ConnectCodeRepository = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/ConnectCodeRepository',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryResponse.FromString,
                _registered_method=True)
        self.GetAccessToken = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/GetAccessToken',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenResponse.FromString,
                _registered_method=True)
        self.GetGithubRepositoriesFromAuthUser = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/GetGithubRepositoriesFromAuthUser',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserResponse.FromString,
                _registered_method=True)
        self.GetUserAccessToken = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/GetUserAccessToken',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenResponse.FromString,
                _registered_method=True)
        self.GetCodeRepos = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/GetCodeRepos',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposResponse.FromString,
                _registered_method=True)
        self.CreateCodeRepo = channel.unary_unary(
                '/admin.v1.CodeRepositoryService/CreateCodeRepo',
                request_serializer=admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoResponse.FromString,
                _registered_method=True)


class CodeRepositoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeleteCodeRepoById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelDeleteCodeRepoById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectCodeRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccessToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGithubRepositoriesFromAuthUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAccessToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCodeRepos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCodeRepo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CodeRepositoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeleteCodeRepoById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCodeRepoById,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdResponse.SerializeToString,
            ),
            'CancelDeleteCodeRepoById': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelDeleteCodeRepoById,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdResponse.SerializeToString,
            ),
            'ConnectCodeRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectCodeRepository,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryResponse.SerializeToString,
            ),
            'GetAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccessToken,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenResponse.SerializeToString,
            ),
            'GetGithubRepositoriesFromAuthUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGithubRepositoriesFromAuthUser,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserResponse.SerializeToString,
            ),
            'GetUserAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAccessToken,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenResponse.SerializeToString,
            ),
            'GetCodeRepos': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCodeRepos,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposResponse.SerializeToString,
            ),
            'CreateCodeRepo': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCodeRepo,
                    request_deserializer=admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.CodeRepositoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.CodeRepositoryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CodeRepositoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeleteCodeRepoById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/DeleteCodeRepoById',
            admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.DeleteCodeRepoByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelDeleteCodeRepoById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/CancelDeleteCodeRepoById',
            admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.CancelDeleteCodeRepoByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConnectCodeRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/ConnectCodeRepository',
            admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.ConnectCodeRepositoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/GetAccessToken',
            admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.GetAccessTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetGithubRepositoriesFromAuthUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/GetGithubRepositoriesFromAuthUser',
            admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.GetGithubRepositoriesFromAuthUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/GetUserAccessToken',
            admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.GetUserAccessTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCodeRepos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/GetCodeRepos',
            admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.GetCodeReposResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateCodeRepo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CodeRepositoryService/CreateCodeRepo',
            admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoRequest.SerializeToString,
            admin_dot_v1_dot_integration__code__repository__pb2.CreateCodeRepoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_cloud.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_cloud.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import flat_dataplane_pb2 as admin_dot_v1_dot_types_dot_v1_dot_flat__dataplane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_cloud.proto\x12\x08\x61\x64min.v1\x1a&admin/v1/types/v1/flat_dataplane.proto\")\n\x17GetDataplaneByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x18GetDataplaneByIdResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\"/\n\x1dGetDataplaneRoutesByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"}\n\x1eGetDataplaneRoutesByIdResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\"\x83\x01\n!CreateAwsConnectionSessionRequest\x12,\n\x12\x63loud_account_name\x18\x01 \x01(\tR\x10\x63loudAccountName\x12\x30\n\x14\x63loud_account_region\x18\x02 \x01(\tR\x12\x63loudAccountRegion\"v\n\"CreateAwsConnectionSessionResponse\x12P\n\x11\x63loud_integration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x10\x63loudIntegration\"3\n!DeleteAwsConnectionSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"8\n&GetIntegrationsCloudAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"p\n\'GetIntegrationsCloudAccountByIdResponse\x12\x45\n\x0bintegration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0bintegration\"%\n#GetIntegrationsCloudAccountsRequest\"o\n$GetIntegrationsCloudAccountsResponse\x12G\n\x0cintegrations\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0cintegrations\"B\n!CreateGcpConnectionSessionRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"$\n\"CreateGcpConnectionSessionResponse\"$\n\"DeleteAwsConnectionSessionResponse\"U\n)GetDataplaneStacksByCloudAccountIdRequest\x12(\n\x10\x63loud_account_id\x18\x01 \x01(\tR\x0e\x63loudAccountId\"n\n*GetDataplaneStacksByCloudAccountIdResponse\x12@\n\ndataplanes\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\ndataplanes2\xdb\x07\n\x0c\x43loudService\x12Y\n\x10GetDataplaneById\x12!.admin.v1.GetDataplaneByIdRequest\x1a\".admin.v1.GetDataplaneByIdResponse\x12k\n\x16GetDataplaneRoutesById\x12\'.admin.v1.GetDataplaneRoutesByIdRequest\x1a(.admin.v1.GetDataplaneRoutesByIdResponse\x12\x8f\x01\n\"GetDataplaneStacksByCloudAccountId\x12\x33.admin.v1.GetDataplaneStacksByCloudAccountIdRequest\x1a\x34.admin.v1.GetDataplaneStacksByCloudAccountIdResponse\x12w\n\x1a\x43reateAwsConnectionSession\x12+.admin.v1.CreateAwsConnectionSessionRequest\x1a,.admin.v1.CreateAwsConnectionSessionResponse\x12w\n\x1a\x44\x65leteAwsConnectionSession\x12+.admin.v1.DeleteAwsConnectionSessionRequest\x1a,.admin.v1.DeleteAwsConnectionSessionResponse\x12\x86\x01\n\x1fGetIntegrationsCloudAccountById\x12\x30.admin.v1.GetIntegrationsCloudAccountByIdRequest\x1a\x31.admin.v1.GetIntegrationsCloudAccountByIdResponse\x12}\n\x1cGetIntegrationsCloudAccounts\x12-.admin.v1.GetIntegrationsCloudAccountsRequest\x1a..admin.v1.GetIntegrationsCloudAccountsResponse\x12w\n\x1a\x43reateGcpConnectionSession\x12+.admin.v1.CreateGcpConnectionSessionRequest\x1a,.admin.v1.CreateGcpConnectionSessionResponseB\xab\x01\n\x0c\x63om.admin.v1B\x15IntegrationCloudProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_cloud_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationCloudProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_start=86
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_end=127
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_start=129
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_end=219
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_start=221
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_end=268
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_start=270
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_end=395
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_start=398
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_end=529
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=531
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=649
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_start=651
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_end=702
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_start=704
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_end=760
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_start=762
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_end=874
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_start=876
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_end=913
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_start=915
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_end=1026
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_start=1028
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_end=1094
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_start=1096
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_end=1132
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1134
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1170
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_start=1172
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_end=1257
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_start=1259
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_end=1369
  _globals['_CLOUDSERVICE']._serialized_start=1372
  _globals['_CLOUDSERVICE']._serialized_end=2359
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSlackIntegrationRequest(_message.Message):
    __slots__ = ("code", "redirect_uri")
    CODE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    code: str
    redirect_uri: str
    def __init__(self, code: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class CreateSlackIntegrationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSlackIntegrationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSlackIntegrationResponse(_message.Message):
    __slots__ = ("is_connected", "slack")
    class SlackIntegration(_message.Message):
        __slots__ = ("team_id", "team_name", "bot_user_id", "bot_access_token", "authed_user_id", "channel_id")
        TEAM_ID_FIELD_NUMBER: _ClassVar[int]
        TEAM_NAME_FIELD_NUMBER: _ClassVar[int]
        BOT_USER_ID_FIELD_NUMBER: _ClassVar[int]
        BOT_ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
        AUTHED_USER_ID_FIELD_NUMBER: _ClassVar[int]
        CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
        team_id: str
        team_name: str
        bot_user_id: str
        bot_access_token: str
        authed_user_id: str
        channel_id: str
        def __init__(self, team_id: _Optional[str] = ..., team_name: _Optional[str] = ..., bot_user_id: _Optional[str] = ..., bot_access_token: _Optional[str] = ..., authed_user_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...
    IS_CONNECTED_FIELD_NUMBER: _ClassVar[int]
    SLACK_FIELD_NUMBER: _ClassVar[int]
    is_connected: bool
    slack: GetSlackIntegrationResponse.SlackIntegration
    def __init__(self, is_connected: bool = ..., slack: _Optional[_Union[GetSlackIntegrationResponse.SlackIntegration, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/column.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/column.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/column.proto\x12\x11\x61\x64min.v1.types.v1\"\xd9\x05\n\x06\x43olumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12#\n\rpolicy_action\x18\x11 \x01(\tR\x0cpolicyAction\x12\x35\n\x17\x64\x65\x63rypted_at_query_time\x18\x12 \x01(\x08R\x14\x64\x65\x63ryptedAtQueryTime\x12\x30\n\x14\x64\x65\x63ryption_policy_id\x18\x13 \x01(\tR\x12\x64\x65\x63ryptionPolicyId\x12&\n\x0f\x64\x61ta_domain_ids\x18\x14 \x03(\tR\rdataDomainIdsB\xd9\x01\n\x15\x63om.admin.v1.types.v1B\x0b\x43olumnProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.column_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013ColumnProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_COLUMN']._serialized_start=54
  _globals['_COLUMN']._serialized_end=783
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class InstallGithubAppRequest(_message.Message):
    __slots__ = ("installation_id",)
    INSTALLATION_ID_FIELD_NUMBER: _ClassVar[int]
    installation_id: str
    def __init__(self, installation_id: _Optional[str] = ...) -> None: ...

class InstallGithubAppResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetGithubAppForOrgRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetGithubAppForOrgResponse(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...



import grpc


from .gen.admin.v1.encryption_pb2 import (
	CreateOrUpdateDefaultFieldEncryptionPolicyRequest,
	CreateOrUpdateDefaultFieldEncryptionPolicyResponse,
	GetDefaultFieldEncryptionPolicyRequest,
	GetDefaultFieldEncryptionPolicyResponse,
	DefaultFieldEncryptionPolicy,
	CreateFieldEncryptionRequest,
	CreateFieldEncryptionResponse,
	GetFieldEncryptionsByDatastoreRequest,
	GetFieldEncryptionsByDatastoreResponse,
	DeleteFieldEncryptionRequest,
	DeleteFieldEncryptionResponse,
	FieldEncryption,
)

from .gen.admin.v1.encryption_pb2_grpc import FieldEncryptionPolicyServiceStub
class FieldEncryptionPolicyService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = FieldEncryptionPolicyServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateOrUpdateDefaultFieldEncryptionPolicy(self, request: CreateOrUpdateDefaultFieldEncryptionPolicyRequest) -> CreateOrUpdateDefaultFieldEncryptionPolicyResponse:
		return self.stub.CreateOrUpdateDefaultFieldEncryptionPolicy(request, metadata=self.headers)

	def GetDefaultFieldEncryptionPolicy(self, request: GetDefaultFieldEncryptionPolicyRequest) -> GetDefaultFieldEncryptionPolicyResponse:
		return self.stub.GetDefaultFieldEncryptionPolicy(request, metadata=self.headers)

from .gen.admin.v1.encryption_pb2_grpc import FieldEncryptionServiceStub
class FieldEncryptionService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = FieldEncryptionServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateFieldEncryption(self, request: CreateFieldEncryptionRequest) -> CreateFieldEncryptionResponse:
		return self.stub.CreateFieldEncryption(request, metadata=self.headers)

	def GetFieldEncryptionsByDatastore(self, request: GetFieldEncryptionsByDatastoreRequest) -> GetFieldEncryptionsByDatastoreResponse:
		return self.stub.GetFieldEncryptionsByDatastore(request, metadata=self.headers)

	def DeleteFieldEncryption(self, request: DeleteFieldEncryptionRequest) -> DeleteFieldEncryptionResponse:
		return self.stub.DeleteFieldEncryption(request, metadata=self.headers)




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IntegrationLogs(_message.Message):
    __slots__ = ("id", "name", "type", "created_at", "dd_site", "dd_account_id", "splunk_url", "aws_s3_bucket_name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DD_SITE_FIELD_NUMBER: _ClassVar[int]
    DD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    SPLUNK_URL_FIELD_NUMBER: _ClassVar[int]
    AWS_S3_BUCKET_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: str
    created_at: int
    dd_site: str
    dd_account_id: str
    splunk_url: str
    aws_s3_bucket_name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., created_at: _Optional[int] = ..., dd_site: _Optional[str] = ..., dd_account_id: _Optional[str] = ..., splunk_url: _Optional[str] = ..., aws_s3_bucket_name: _Optional[str] = ...) -> None: ...



import grpc


from .gen.admin.v1.metrics_pb2 import (
	GetMetricsRequest,
	Metric,
	Node,
	Link,
	GetMetricsResponse,
	RowLevelMetric,
	RowLevelMetricConfiguration,
	GetCustomMetricsDetailsRequest,
	GetCustomMetricsDetailsResponse,
	MetricsGroup,
	GetCustomMetricsRequest,
	GetCustomMetricsResponse,
	CreateCustomMetricRequest,
	CreateCustomMetricResponse,
	DeleteCustomMetricRequest,
	DeleteCustomMetricResponse,
)

from .gen.admin.v1.metrics_pb2_grpc import MetricsServiceStub
class MetricsService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = MetricsServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetMetrics(self, request: GetMetricsRequest) -> GetMetricsResponse:
		return self.stub.GetMetrics(request, metadata=self.headers)

	def CreateCustomMetric(self, request: CreateCustomMetricRequest) -> CreateCustomMetricResponse:
		return self.stub.CreateCustomMetric(request, metadata=self.headers)

	def GetCustomMetrics(self, request: GetCustomMetricsRequest) -> GetCustomMetricsResponse:
		return self.stub.GetCustomMetrics(request, metadata=self.headers)

	def GetCustomMetricsDetails(self, request: GetCustomMetricsDetailsRequest) -> GetCustomMetricsDetailsResponse:
		return self.stub.GetCustomMetricsDetails(request, metadata=self.headers)

	def DeleteCustomMetric(self, request: DeleteCustomMetricRequest) -> DeleteCustomMetricResponse:
		return self.stub.DeleteCustomMetric(request, metadata=self.headers)




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import datastore_pb2 as admin_dot_v1_dot_datastore__pb2


class DataStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/CreateDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.FromString,
                _registered_method=True)
        self.GetDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/GetDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.FromString,
                _registered_method=True)
        self.GetDatastores = channel.unary_unary(
                '/admin.v1.DataStoreService/GetDatastores',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.FromString,
                _registered_method=True)
        self.GetLinkedSidecars = channel.unary_unary(
                '/admin.v1.DataStoreService/GetLinkedSidecars',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.FromString,
                _registered_method=True)
        self.DeleteDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/DeleteDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.FromString,
                _registered_method=True)
        self.UpdateDatastoreName = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDatastoreName',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.FromString,
                _registered_method=True)
        self.UpdateDbDiscoveryConfig = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDbDiscoveryConfig',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.FromString,
                _registered_method=True)
        self.UpdateDataStoreHealthCheckDbName = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDataStoreHealthCheckDbName',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.FromString,
                _registered_method=True)
        self.UpdateDataStoreDefaultAccessBehavior = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDataStoreDefaultAccessBehavior',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.FromString,
                _registered_method=True)
        self.SetTerminationProtection = channel.unary_unary(
                '/admin.v1.DataStoreService/SetTerminationProtection',
                request_serializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.FromString,
                _registered_method=True)


class DataStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinkedSidecars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatastoreName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDbDiscoveryConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataStoreHealthCheckDbName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataStoreDefaultAccessBehavior(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTerminationProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.SerializeToString,
            ),
            'GetDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.SerializeToString,
            ),
            'GetDatastores': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatastores,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.SerializeToString,
            ),
            'GetLinkedSidecars': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinkedSidecars,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.SerializeToString,
            ),
            'DeleteDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.SerializeToString,
            ),
            'UpdateDatastoreName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatastoreName,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.SerializeToString,
            ),
            'UpdateDbDiscoveryConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDbDiscoveryConfig,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.SerializeToString,
            ),
            'UpdateDataStoreHealthCheckDbName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataStoreHealthCheckDbName,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.SerializeToString,
            ),
            'UpdateDataStoreDefaultAccessBehavior': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataStoreDefaultAccessBehavior,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.SerializeToString,
            ),
            'SetTerminationProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTerminationProtection,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.DataStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.DataStoreService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/CreateDatastore',
            admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetDatastore',
            admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatastores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetDatastores',
            admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLinkedSidecars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetLinkedSidecars',
            admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/DeleteDatastore',
            admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDatastoreName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDatastoreName',
            admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDbDiscoveryConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDbDiscoveryConfig',
            admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDataStoreHealthCheckDbName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDataStoreHealthCheckDbName',
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDataStoreDefaultAccessBehavior(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDataStoreDefaultAccessBehavior',
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetTerminationProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/SetTerminationProtection',
            admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_mfa_pb2 as admin_dot_v1_dot_integration__mfa__pb2


class IntegrationMfaServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntegrationMfas = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/ListIntegrationMfas',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.FromString,
                _registered_method=True)
        self.GetIntegrationMfaById = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/GetIntegrationMfaById',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.FromString,
                _registered_method=True)
        self.UpdateIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/UpdateIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.FromString,
                _registered_method=True)
        self.CreateIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/CreateIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.FromString,
                _registered_method=True)
        self.DeleteIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/DeleteIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.FromString,
                _registered_method=True)


class IntegrationMfaServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListIntegrationMfas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationMfaById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationMfaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListIntegrationMfas': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrationMfas,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.SerializeToString,
            ),
            'GetIntegrationMfaById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationMfaById,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.SerializeToString,
            ),
            'UpdateIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.SerializeToString,
            ),
            'CreateIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.SerializeToString,
            ),
            'DeleteIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.IntegrationMfaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.IntegrationMfaService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IntegrationMfaService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListIntegrationMfas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/ListIntegrationMfas',
            admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationMfaById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/GetIntegrationMfaById',
            admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/UpdateIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/CreateIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/DeleteIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
